==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/pages.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include("include/header.inc.php");

	$sql	= "SELECT *,UNIX_TIMESTAMP(Birthstamp) AS Birthstamp,";
	$sql	.= "UNIX_TIMESTAMP(Timestamp) AS Timestamp from T_Blocks";
	$sql	.= " WHERE Rid = '$page' LIMIT 1";
	$A	= SqlQueryFetchArray($sql);
	if (!$A) {
		$VAR["Heading"] = _NO_PAGE_HEAD;
		$VAR["Content"] = _NO_PAGE_DESC . "<BR><BR>";
		KWL_DrawMain($VAR);
	} else {
		KWL_UpHits("T_Blocks",$A["Rid"]);
		$A["Content"]	= KWL_GetContent($A);
		$A["Content"]	.= "<br>\n" . KWL_AdminLinki("T_Blocks",$A["Rid"],"pages.php?page=$page");
		KWL_DrawMain($A);

		if ($A["PageComments"]) {
			/* override user value */
			if ($cmode == "thread") $cmode = "nest";
			$CONF['SCORING'] = 0; $score = -1;
						
			if (SqlCount("T_Comments","TopRid","$A[Rid]")) 
				KWL_SortComment("pages.php?page=$page",0);
			KWL_doComments($A["Rid"],$A["Rid"],"pages.php?page=$page");
			print "<P>";
			KWL_PostComment($A["Rid"],$A["Rid"],"pages.php?page=$page");
		}
	}
	include("include/footer.inc.php");
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/pages.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include("include/header.inc.php");

	$sql	= "SELECT *,UNIX_TIMESTAMP(Birthstamp) AS Birthstamp,";
	$sql	.= "UNIX_TIMESTAMP(Timestamp) AS Timestamp from T_Blocks";
	$sql	.= " WHERE Rid = '$page' LIMIT 1";
	$A	= SqlQueryFetchArray($sql);
	if (!$A) {
		$VAR["Heading"] = _NO_PAGE_HEAD;
		$VAR["Content"] = _NO_PAGE_DESC . "<br /><br />";
		KWL_DrawMain($VAR);
	} else {
		KWL_UpHits("T_Blocks",$A["Rid"]);
		$A["Content"]	= KWL_GetContent($A);
		$A["Content"]	.= "<br />\n" . KWL_AdminLinki("T_Blocks",$A["Rid"],"pages.php?page=$page");
		KWL_DrawMain($A);

		if ($A["PageComments"]) {
			/* override user value */
			if ($cmode == "thread") $cmode = "nest";
			$CONF['SCORING'] = 0; $score = -1;
						
			if (SqlCount("T_Comments","TopRid","$A[Rid]")) 
				KWL_SortComment("pages.php?page=$page",0);
			KWL_doComments($A["Rid"],$A["Rid"],"pages.php?page=$page");
			print "<p />";
			KWL_PostComment($A["Rid"],$A["Rid"],"pages.php?page=$page");
		}
	}
	include("include/footer.inc.php");
?>
